@@ -5,24 +5,25 @@ import sys
 from pathlib import Path
 
 from brownie import network
-from brownie._config import ARGV
+from brownie._config import CONFIG
 from brownie.exceptions import ProjectNotFound
 from brownie.utils import color, notify
 from brownie.utils.docopt import docopt, levenshtein_norm
 
-__version__ = "1.6.8"
+__version__ = "1.7.4"
 
 __doc__ = """Usage:  brownie <command> [<args>...] [options <args>]
 
 Commands:
   init               Initialize a new brownie project
   bake               Initialize from a brownie-mix template
-  ethpm              Commands related to the ethPM package manager
-  compile            Compiles the contract source files
+  pm                 Install and manage external packages
+  compile            Compile the contract source files
   console            Load the console
   test               Run test cases in the tests/ folder
   run                Run a script in the scripts/ folder
   accounts           Manage local accounts
+  networks           Manage network settings
   gui                Load the GUI to view opcodes and test coverage
   analyze            Find security vulnerabilities using the MythX API
 
@@ -49,7 +50,7 @@ def main():
             sys.exit(f"Invalid command. Did you mean 'brownie {distances[0][0]}'?")
         sys.exit("Invalid command. Try 'brownie --help' for available commands.")
 
-    ARGV["cli"] = cmd
+    CONFIG.argv["cli"] = cmd
     sys.modules["brownie"].a = network.accounts
     sys.modules["brownie"].__all__.append("a")
 
