@@ -2,6 +2,8 @@
 
 from typing import Dict, List, Optional, Tuple
 
+from eth_hash.auto import keccak
+
 
 def get_int_bounds(type_str: str) -> Tuple[int, int]:
     """Returns the lower and upper bound for an integer type."""
@@ -19,13 +21,26 @@ def get_type_strings(abi_params: List, substitutions: Optional[Dict] = None) ->
     if substitutions is None:
         substitutions = {}
     for i in abi_params:
-        if i["type"] != "tuple":
+        if i["type"] == "tuple":
+            params = get_type_strings(i["components"], substitutions)
+            types_list.append(f"({','.join(params)})")
+        elif i["type"] == "tuple[]":
+            params = get_type_strings(i["components"], substitutions)
+            types_list.append(f"({','.join(params)})[]")
+        else:
             type_str = i["type"]
             for orig, sub in substitutions.items():
                 if type_str.startswith(orig):
                     type_str = type_str.replace(orig, sub)
             types_list.append(type_str)
-            continue
-        params = get_type_strings(i["components"], substitutions)
-        types_list.append(f"({','.join(params)})")
     return types_list
+
+
+def build_function_signature(abi: Dict) -> str:
+    types_list = get_type_strings(abi["inputs"])
+    return f"{abi['name']}({','.join(types_list)})"
+
+
+def build_function_selector(abi: Dict) -> str:
+    sig = build_function_signature(abi)
+    return "0x" + keccak(sig.encode()).hex()[:8]
