@@ -1,19 +1,28 @@
 #!/usr/bin/python3
 
 import json
+import os
 import re
+import warnings
 from pathlib import Path
-from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union
+from textwrap import TextWrapper
+from typing import Any, Callable, Dict, Iterator, List, Optional, Set, Tuple, Union
+from urllib.parse import urlparse
 
 import eth_abi
-from eth_hash.auto import keccak
+import requests
 from eth_utils import remove_0x_prefix
 from hexbytes import HexBytes
+from semantic_version import Version
 
-from brownie._config import ARGV, CONFIG
+from brownie._config import CONFIG
 from brownie.convert.datatypes import Wei
 from brownie.convert.normalize import format_input, format_output
-from brownie.convert.utils import get_type_strings
+from brownie.convert.utils import (
+    build_function_selector,
+    build_function_signature,
+    get_type_strings,
+)
 from brownie.exceptions import (
     ContractExists,
     ContractNotFound,
@@ -21,29 +30,48 @@ from brownie.exceptions import (
     VirtualMachineError,
 )
 from brownie.project import ethpm
+from brownie.project.compiler import compile_and_format
 from brownie.typing import AccountsType, TransactionReceiptType
 from brownie.utils import color
 
+from . import accounts, rpc
 from .event import _get_topics
-from .rpc import Rpc, _revert_register
-from .state import _add_contract, _find_contract, _remove_contract
+from .rpc import _revert_register
+from .state import _add_contract, _add_deployment, _find_contract, _get_deployment, _remove_contract
 from .web3 import _resolve_address, web3
 
 __tracebackhide__ = True
-rpc = Rpc()
+
+_unverified_addresses: Set = set()
 
 
 class _ContractBase:
 
     _dir_color = "bright magenta"
 
-    def __init__(self, project: Any, build: Dict, name: str, abi: List) -> None:
+    def __init__(self, project: Any, build: Dict, sources: Dict) -> None:
         self._project = project
-        self._build = build
-        self._name = name
-        self.abi = abi
-        self.topics = _get_topics(abi)
-        self.signatures = dict((i["name"], _signature(i)) for i in abi if i["type"] == "function")
+        self._build = build.copy()
+        self._sources = sources
+        self.topics = _get_topics(self.abi)
+        self.signatures = {
+            i["name"]: build_function_selector(i) for i in self.abi if i["type"] == "function"
+        }
+
+    @property
+    def abi(self) -> List:
+        return self._build["abi"]
+
+    @property
+    def _name(self) -> str:
+        return self._build["contractName"]
+
+    def info(self) -> None:
+        """
+        Display NatSpec documentation for this contract.
+        """
+        if self._build.get("natspec"):
+            _print_natspec(self._build["natspec"])
 
     def get_method(self, calldata: str) -> Optional[str]:
         sig = calldata[:10].lower()
@@ -65,7 +93,7 @@ class ContractContainer(_ContractBase):
         self.tx = None
         self.bytecode = build["bytecode"]
         self._contracts: List["ProjectContract"] = []
-        super().__init__(project, build, build["contractName"], build["abi"])
+        super().__init__(project, build, project._sources)
         self.deploy = ContractConstructor(self, self._name)
         _revert_register(self)
 
@@ -87,7 +115,6 @@ class ContractContainer(_ContractBase):
 
     def _reset(self) -> None:
         for contract in self._contracts:
-            contract._delete_deployment()
             _remove_contract(contract)
             contract._reverted = True
         self._contracts.clear()
@@ -128,21 +155,25 @@ class ContractContainer(_ContractBase):
             owner: Default Account instance to send contract transactions from.
             tx: Transaction ID of the contract creation."""
         contract = _find_contract(address)
-        if contract:
+        if isinstance(contract, ProjectContract):
             if contract._name == self._name and contract._project == self._project:
                 return contract
             raise ContractExists(
                 f"'{contract._name}' declared at {address} in project '{contract._project._name}'"
             )
 
-        if _verify_deployed_code(address, self._build["deployedBytecode"]):
-            contract = ProjectContract(self._project, self._build, address, owner, tx)
-        else:
-            contract = Contract(self._name, address, self.abi, owner=owner)
-            contract._project = self._project
+        build = self._build
+        contract = ProjectContract(self._project, build, address, owner, tx)
+        if not _verify_deployed_code(address, build["deployedBytecode"], build["language"]):
+            # prevent trace attempts when the bytecode doesn't match
+            del contract._build["pcMap"]
+
         contract._save_deployment()
         _add_contract(contract)
         self._contracts.append(contract)
+        if CONFIG.network_type == "live":
+            _add_deployment(contract)
+
         return contract
 
     def _add_from_tx(self, tx: TransactionReceiptType) -> None:
@@ -164,6 +195,13 @@ class ContractConstructor:
             self.abi = {"inputs": [], "name": "constructor", "type": "constructor"}
         self._name = name
 
+    @property
+    def payable(self) -> bool:
+        if "payable" in self.abi:
+            return self.abi["payable"]
+        else:
+            return self.abi["stateMutability"] == "payable"
+
     def __repr__(self) -> str:
         return f"<{type(self).__name__} '{self._name}.constructor({_inputs(self.abi)})'>"
 
@@ -188,6 +226,9 @@ class ContractConstructor:
             self._parent, *args, amount=tx["value"], gas_limit=tx["gas"], gas_price=tx["gasPrice"]
         )
 
+    def _autosuggest(self) -> List:
+        return _contract_method_autosuggest(self)
+
     def encode_input(self, *args: tuple) -> str:
         bytecode = self._parent.bytecode
         # find and replace unlinked library pointers in bytecode
@@ -227,16 +268,27 @@ class _DeployedContractBase(_ContractBase):
         self._owner = owner
         self.tx = tx
         self.address = address
+
         fn_names = [i["name"] for i in self.abi if i["type"] == "function"]
         for abi in [i for i in self.abi if i["type"] == "function"]:
             name = f"{self._name}.{abi['name']}"
+            sig = build_function_signature(abi)
+            natspec: Dict = {}
+            if self._build.get("natspec"):
+                natspec = self._build["natspec"]["methods"].get(sig, {})
+
             if fn_names.count(abi["name"]) == 1:
-                self._check_and_set(abi["name"], _get_method_object(address, abi, name, owner))
+                fn = _get_method_object(address, abi, name, owner, natspec)
+                self._check_and_set(abi["name"], fn)
                 continue
+
             if not hasattr(self, abi["name"]):
-                self._check_and_set(abi["name"], OverloadedMethod(address, name, owner))
+                overloaded = OverloadedMethod(address, name, owner)
+                self._check_and_set(abi["name"], overloaded)
+
             key = ",".join(i["type"] for i in abi["inputs"]).replace("256", "")
-            getattr(self, abi["name"]).methods[key] = _get_method_object(address, abi, name, owner)
+            fn = _get_method_object(address, abi, name, owner, natspec)
+            getattr(self, abi["name"]).methods[key] = fn
 
     def _check_and_set(self, name: str, obj: Any) -> None:
         if hasattr(self, name):
@@ -250,7 +302,10 @@ class _DeployedContractBase(_ContractBase):
         return self.address
 
     def __repr__(self) -> str:
-        return f"<{self._name} Contract '{color('bright magenta')}{self.address}{color}'>"
+        alias = self._build.get("alias")
+        if alias:
+            return f"<'{alias}' Contract '{self.address}'>"
+        return f"<{self._name} Contract '{self.address}'>"
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, _DeployedContractBase):
@@ -274,10 +329,10 @@ class _DeployedContractBase(_ContractBase):
         return Wei(balance)
 
     def _deployment_path(self) -> Optional[Path]:
-        if not CONFIG["active_network"].get("persist", None) or not self._project._path:
+        if CONFIG.network_type != "live" or not self._project._path:
             return None
-        network = CONFIG["active_network"]["name"]
-        path = self._project._path.joinpath(f"build/deployments/{network}")
+        chainid = CONFIG.active_network["chainid"]
+        path = self._project._path.joinpath(f"build/deployments/{chainid}")
         path.mkdir(exist_ok=True)
         return path.joinpath(f"{self.address}.json")
 
@@ -294,7 +349,64 @@ class _DeployedContractBase(_ContractBase):
 
 
 class Contract(_DeployedContractBase):
+    """
+    Object to interact with a deployed contract outside of a project.
+    """
+
     def __init__(
+        self, address_or_alias: str, *args: Any, owner: Optional[AccountsType] = None, **kwargs: Any
+    ) -> None:
+        """
+        Recreate a `Contract` object from the local database.
+
+        The init method is used to access deployments that have already previously
+        been stored locally. For new deployments use `from_abi`, `from_ethpm` or
+        `from_etherscan`.
+
+        Arguments
+        ---------
+        address_or_alias : str
+            Address or user-defined alias of the deployment.
+        owner : Account, optional
+            Contract owner. If set, transactions without a `from` field
+            will be performed using this account.
+        """
+        if args or kwargs:
+            warnings.warn(
+                "Initializing `Contract` in this manner is deprecated."
+                " Use `from_abi` or `from_ethpm` instead.",
+                DeprecationWarning,
+            )
+            kwargs["owner"] = owner
+            return self._deprecated_init(address_or_alias, *args, **kwargs)
+
+        address = ""
+        try:
+            address = _resolve_address(address_or_alias)
+            build, sources = _get_deployment(address)
+        except Exception:
+            build, sources = _get_deployment(alias=address_or_alias)
+            if build is not None:
+                address = build["address"]
+
+        if build is None or sources is None:
+            if (
+                not address
+                or not CONFIG.settings.get("autofetch_sources")
+                or not CONFIG.active_network.get("explorer")
+            ):
+                if not address:
+                    raise ValueError(f"Unknown alias: {address_or_alias}")
+                else:
+                    raise ValueError(f"Unknown contract address: {address}")
+            contract = self.from_explorer(address, owner=owner, silent=True)
+            build, sources = contract._build, contract._sources
+            address = contract.address
+
+        _ContractBase.__init__(self, None, build, sources)
+        _DeployedContractBase.__init__(self, address, owner)
+
+    def _deprecated_init(
         self,
         name: str,
         address: Optional[str] = None,
@@ -326,13 +438,220 @@ class Contract(_DeployedContractBase):
             raise TypeError("Address cannot be None unless creating object from manifest")
 
         build = {"abi": abi, "contractName": name, "type": "contract"}
-        _ContractBase.__init__(self, None, build, name, abi)  # type: ignore
+        _ContractBase.__init__(self, None, build, {})  # type: ignore
         _DeployedContractBase.__init__(self, address, owner, None)
-        contract = _find_contract(address)
-        if not contract:
-            return
-        if contract.bytecode != self.bytecode:
-            contract._reverted = True
+
+    @classmethod
+    def from_abi(
+        cls, name: str, address: str, abi: Dict, owner: Optional[AccountsType] = None
+    ) -> "Contract":
+        """
+        Create a new `Contract` object from an ABI.
+
+        Arguments
+        ---------
+        name : str
+            Name of the contract.
+        address : str
+            Address where the contract is deployed.
+        abi : dict
+            Contract ABI, given as a dictionary.
+        owner : Account, optional
+            Contract owner. If set, transactions without a `from` field
+            will be performed using this account.
+        """
+        address = _resolve_address(address)
+        build = {"abi": abi, "address": address, "contractName": name, "type": "contract"}
+
+        self = cls.__new__(cls)
+        _ContractBase.__init__(self, None, build, {})  # type: ignore
+        _DeployedContractBase.__init__(self, address, owner, None)
+        _add_deployment(self)
+        return self
+
+    @classmethod
+    def from_ethpm(
+        cls,
+        name: str,
+        manifest_uri: str,
+        address: Optional[str] = None,
+        owner: Optional[AccountsType] = None,
+    ) -> "Contract":
+        """
+        Create a new `Contract` object from an ethPM manifest.
+
+        Arguments
+        ---------
+        name : str
+            Name of the contract.
+        manifest_uri : str
+            erc1319 registry URI where the manifest is located
+        address : str optional
+            Address where the contract is deployed. Only required if the
+            manifest contains more than one deployment with the given name
+            on the active chain.
+        owner : Account, optional
+            Contract owner. If set, transactions without a `from` field
+            will be performed using this account.
+        """
+        manifest = ethpm.get_manifest(manifest_uri)
+
+        if address is None:
+            address_list = ethpm.get_deployment_addresses(manifest, name)
+            if not address_list:
+                raise ContractNotFound(
+                    f"'{manifest['package_name']}' manifest does not contain"
+                    f" a deployment of '{name}' on this chain"
+                )
+            if len(address_list) > 1:
+                raise ValueError(
+                    f"'{manifest['package_name']}' manifest contains more than one "
+                    f"deployment of '{name}' on this chain, you must specify an address:"
+                    f" {', '.join(address_list)}"
+                )
+            address = address_list[0]
+
+        manifest["contract_types"][name]["contract_name"]
+        build = {
+            "abi": manifest["contract_types"][name]["abi"],
+            "contractName": name,
+            "natspec": manifest["contract_types"][name]["natspec"],
+            "type": "contract",
+        }
+
+        self = cls.__new__(cls)
+        _ContractBase.__init__(self, None, build, manifest["sources"])  # type: ignore
+        _DeployedContractBase.__init__(self, address, owner)
+        _add_deployment(self)
+        return self
+
+    @classmethod
+    def from_explorer(
+        cls,
+        address: str,
+        as_proxy_for: Optional[str] = None,
+        owner: Optional[AccountsType] = None,
+        silent: bool = False,
+    ) -> "Contract":
+        """
+        Create a new `Contract` object with source code queried from a block explorer.
+
+        Arguments
+        ---------
+        address : str
+            Address where the contract is deployed.
+        as_proxy_for : str, optional
+            Address of the implementation contract, if `address` is a proxy contract.
+            The generated object will send transactions to `address`, but use the ABI
+            and NatSpec of `as_proxy_for`.
+        owner : Account, optional
+            Contract owner. If set, transactions without a `from` field will be
+            performed using this account.
+        """
+        url = CONFIG.active_network.get("explorer")
+        if url is None:
+            raise ValueError("Explorer API not set for this network")
+
+        address = _resolve_address(address)
+        if address in _unverified_addresses:
+            raise ValueError(f"Source for {address} has not been verified")
+
+        params: Dict = {"module": "contract", "action": "getsourcecode", "address": address}
+        if "etherscan" in url:
+            if os.getenv("ETHERSCAN_TOKEN"):
+                params["apiKey"] = os.getenv("ETHERSCAN_TOKEN")
+            elif not silent:
+                warnings.warn(
+                    "No Etherscan API token set. You may experience issues with rate limiting. "
+                    "Visit https://etherscan.io/register to obtain a token, and then store it "
+                    "as the environment variable $ETHERSCAN_TOKEN"
+                )
+
+        if not silent:
+            print(
+                f"Fetching source of {color('bright blue')}{address}{color} "
+                f"from {color('bright blue')}{urlparse(url).netloc}{color}..."
+            )
+        response = requests.get(url, params=params)
+
+        if response.status_code != 200:
+            raise ConnectionError(
+                f"Status {response.status_code} when querying {url}: {response.text}"
+            )
+        data = response.json()
+        if int(data["status"]) != 1:
+            raise ValueError(f"Failed to retrieve data from API: {data['result']}")
+        if not data["result"][0].get("SourceCode"):
+            _unverified_addresses.add(address)
+            raise ValueError(f"Source for {address} has not been verified")
+
+        if as_proxy_for is not None:
+            implementation_contract = Contract.from_explorer(as_proxy_for)
+            abi = implementation_contract._build["abi"]
+        else:
+            abi = json.loads(data["result"][0]["ABI"])
+
+        name = data["result"][0]["ContractName"]
+        try:
+            version = Version(data["result"][0]["CompilerVersion"].lstrip("v")).truncate()
+        except Exception:
+            version = Version("0.0.0")
+        if version < Version("0.4.22"):
+            if not silent:
+                warnings.warn(
+                    f"{address}: target compiler '{data['result'][0]['CompilerVersion']}' is "
+                    "unsupported by Brownie. Some functionality will not be available."
+                )
+            return cls.from_abi(name, address, abi)
+
+        sources = {f"{name}-flattened.sol": data["result"][0]["SourceCode"]}
+        optimizer = {
+            "enabled": bool(int(data["result"][0]["OptimizationUsed"])),
+            "runs": int(data["result"][0]["Runs"]),
+        }
+        build = compile_and_format(sources, solc_version=str(version), optimizer=optimizer)
+        build = build[name]
+        if as_proxy_for is not None:
+            build.update(abi=abi, natspec=implementation_contract._build["natspec"])
+
+        if not _verify_deployed_code(address, build["deployedBytecode"], build["language"]):
+            warnings.warn(f"{address}: Locally compiled and on-chain bytecode do not match!")
+            del build["pcMap"]
+
+        self = cls.__new__(cls)
+        _ContractBase.__init__(self, None, build, sources)  # type: ignore
+        _DeployedContractBase.__init__(self, address, owner)
+        _add_deployment(self)
+        return self
+
+    def set_alias(self, alias: Optional[str]) -> None:
+        """
+        Apply a unique alias this object. The alias can be used to restore the
+        object in future sessions.
+
+        Arguments
+        ---------
+        alias: str | None
+            An alias to apply. If `None`, any existing alias is removed.
+        """
+        if CONFIG.network_type != "live":
+            raise ValueError("Cannot set alias outside of live environment")
+
+        if alias is not None:
+            if "." in alias or alias.lower().startswith("0x"):
+                raise ValueError("Invalid alias")
+            build, _ = _get_deployment(alias=alias)
+            if build is not None:
+                if build["address"] != self.address:
+                    raise ValueError("Alias is already in use on another contract")
+                return
+
+        _add_deployment(self, alias)
+        self._build["alias"] = alias
+
+    @property
+    def alias(self) -> Optional[str]:
+        return self._build.get("alias")
 
 
 class ProjectContract(_DeployedContractBase):
@@ -347,7 +666,7 @@ class ProjectContract(_DeployedContractBase):
         owner: Optional[AccountsType] = None,
         tx: TransactionReceiptType = None,
     ) -> None:
-        _ContractBase.__init__(self, project, build, build["contractName"], build["abi"])
+        _ContractBase.__init__(self, project, build, project._sources)
         _DeployedContractBase.__init__(self, address, owner, tx)
 
 
@@ -375,21 +694,42 @@ class _ContractMethod:
 
     _dir_color = "bright magenta"
 
-    def __init__(self, address: str, abi: Dict, name: str, owner: Optional[AccountsType]) -> None:
+    def __init__(
+        self,
+        address: str,
+        abi: Dict,
+        name: str,
+        owner: Optional[AccountsType],
+        natspec: Optional[Dict] = None,
+    ) -> None:
         self._address = address
         self._name = name
         self.abi = abi
         self._owner = owner
-        self.signature = _signature(abi)
+        self.signature = build_function_selector(abi)
+        self.natspec = natspec or {}
 
     def __repr__(self) -> str:
-        if "payable" in self.abi:
-            pay_bool = self.abi["payable"]
-        else:
-            pay_bool = self.abi["stateMutability"] == "payable"
-        pay = "payable " if pay_bool else ""
+        pay = "payable " if self.payable else ""
         return f"<{type(self).__name__} {pay}'{self.abi['name']}({_inputs(self.abi)})'>"
 
+    @property
+    def payable(self) -> bool:
+        if "payable" in self.abi:
+            return self.abi["payable"]
+        else:
+            return self.abi["stateMutability"] == "payable"
+
+    def _autosuggest(self) -> List:
+        return _contract_method_autosuggest(self)
+
+    def info(self) -> None:
+        """
+        Display NatSpec documentation for this method.
+        """
+        print(f"{self.abi['name']}({_inputs(self.abi)})")
+        _print_natspec(self.natspec)
+
     def call(self, *args: Tuple) -> Any:
         """Calls the contract method without broadcasting a transaction.
 
@@ -469,11 +809,6 @@ class ContractTx(_ContractMethod):
         abi: Contract ABI specific to this method.
         signature: Bytes4 method signature."""
 
-    def __init__(self, address: str, abi: Dict, name: str, owner: Optional[AccountsType]) -> None:
-        if ARGV["cli"] == "test" and CONFIG["pytest"]["default_contract_owner"] is False:
-            owner = None
-        super().__init__(address, abi, name, owner)
-
     def __call__(self, *args: Tuple) -> TransactionReceiptType:
         """Broadcasts a transaction that calls this contract method.
 
@@ -505,11 +840,11 @@ class ContractCall(_ContractMethod):
         Returns:
             Contract method return value(s)."""
 
-        if not ARGV["always_transact"]:
+        if not CONFIG.argv["always_transact"]:
             return self.call(*args)
         rpc._internal_snap()
         args, tx = _get_tx(self._owner, args)
-        tx["gas_price"] = 0
+        tx.update({"gas_price": 0, "from": self._owner or accounts[0]})
         try:
             tx = self.transact(*args, tx)
             return tx.return_value
@@ -518,6 +853,13 @@ class ContractCall(_ContractMethod):
 
 
 def _get_tx(owner: Optional[AccountsType], args: Tuple) -> Tuple:
+    # set / remove default sender
+    if owner is None:
+        owner = accounts.default
+    default_owner = CONFIG.active_network["settings"]["default_contract_owner"]
+    if CONFIG.mode == "test" and default_owner is False:
+        owner = None
+
     # seperate contract inputs from tx dict and set default tx values
     tx = {"from": owner, "value": 0, "gas": None, "gasPrice": None}
     if args and isinstance(args[-1], dict):
@@ -530,7 +872,7 @@ def _get_tx(owner: Optional[AccountsType], args: Tuple) -> Tuple:
 
 
 def _get_method_object(
-    address: str, abi: Dict, name: str, owner: Optional[AccountsType]
+    address: str, abi: Dict, name: str, owner: Optional[AccountsType], natspec: Dict
 ) -> Union["ContractCall", "ContractTx"]:
 
     if "constant" in abi:
@@ -539,23 +881,19 @@ def _get_method_object(
         constant = abi["stateMutability"] in ("view", "pure")
 
     if constant:
-        return ContractCall(address, abi, name, owner)
-    return ContractTx(address, abi, name, owner)
+        return ContractCall(address, abi, name, owner, natspec)
+    return ContractTx(address, abi, name, owner, natspec)
 
 
 def _inputs(abi: Dict) -> str:
     types_list = get_type_strings(abi["inputs"], {"fixed168x10": "decimal"})
     params = zip([i["name"] for i in abi["inputs"]], types_list)
-    return ", ".join(f"{i[1]}{' '+i[0] if i[0] else ''}" for i in params)
+    return ", ".join(
+        f"{i[1]}{color('bright blue')}{' '+i[0] if i[0] else ''}{color}" for i in params
+    )
 
 
-def _signature(abi: Dict) -> str:
-    types_list = get_type_strings(abi["inputs"])
-    key = f"{abi['name']}({','.join(types_list)})".encode()
-    return "0x" + keccak(key).hex()[:8]
-
-
-def _verify_deployed_code(address: str, expected_bytecode: str) -> bool:
+def _verify_deployed_code(address: str, expected_bytecode: str, language: str) -> bool:
     actual_bytecode = web3.eth.getCode(address).hex()[2:]
     expected_bytecode = remove_0x_prefix(expected_bytecode)  # type: ignore
 
@@ -572,4 +910,46 @@ def _verify_deployed_code(address: str, expected_bytecode: str) -> bool:
             actual_bytecode = actual_bytecode[:idx] + actual_bytecode[idx + 40 :]
             expected_bytecode = expected_bytecode[:idx] + expected_bytecode[idx + 40 :]
 
+    if language == "Solidity":
+        # do not include metadata in comparison
+        idx = -(int(actual_bytecode[-4:], 16) + 2) * 2
+        actual_bytecode = actual_bytecode[:idx]
+        idx = -(int(expected_bytecode[-4:], 16) + 2) * 2
+        expected_bytecode = expected_bytecode[:idx]
+
     return actual_bytecode == expected_bytecode
+
+
+def _print_natspec(natspec: Dict) -> None:
+    wrapper = TextWrapper(initial_indent=f"  {color('bright magenta')}")
+    for key in [i for i in ("title", "notice", "author", "details") if i in natspec]:
+        wrapper.subsequent_indent = " " * (len(key) + 4)
+        print(wrapper.fill(f"@{key} {color}{natspec[key]}"))
+
+    for key, value in natspec.get("params", {}).items():
+        wrapper.subsequent_indent = " " * 9
+        print(wrapper.fill(f"@param {color('bright blue')}{key}{color} {value}"))
+
+    if "return" in natspec:
+        wrapper.subsequent_indent = " " * 10
+        print(wrapper.fill(f"@return {color}{natspec['return']}"))
+
+    for key in sorted(natspec.get("returns", [])):
+        wrapper.subsequent_indent = " " * 10
+        print(wrapper.fill(f"@return {color}{natspec['returns'][key]}"))
+
+    print()
+
+
+def _contract_method_autosuggest(method: Any) -> List:
+    types_list = get_type_strings(method.abi["inputs"], {"fixed168x10": "decimal"})
+    params = zip([i["name"] for i in method.abi["inputs"]], types_list)
+
+    if isinstance(method, ContractCall):
+        tx_hint: List = []
+    elif method.payable:
+        tx_hint = [" {'from': Account", " 'value': Wei}"]
+    else:
+        tx_hint = [" {'from': Account}"]
+
+    return [f" {i[1]}{' '+i[0] if i[0] else ''}" for i in params] + tx_hint
