@@ -11,7 +11,7 @@ from eth_abi import decode_abi
 from hexbytes import HexBytes
 from web3.exceptions import TransactionNotFound
 
-from brownie._config import ARGV
+from brownie._config import CONFIG
 from brownie.convert import EthAddress, Wei
 from brownie.exceptions import RPCRequestError, VirtualMachineError
 from brownie.project import build
@@ -135,7 +135,7 @@ class TransactionReceipt:
             revert_data: (revert string, program counter, revert type)
         """
 
-        if ARGV["cli"] == "test":
+        if CONFIG.mode == "test":
             silent = True
         if isinstance(txid, bytes):
             txid = txid.hex()
@@ -179,10 +179,14 @@ class TransactionReceipt:
         confirm_thread.start()
         try:
             confirm_thread.join()
-            if ARGV["cli"] == "console":
+            if CONFIG.mode == "console":
                 return
             # if coverage evaluation is active, evaluate the trace
-            if ARGV["coverage"] and not coverage._check_cached(self.coverage_hash) and self.trace:
+            if (
+                CONFIG.argv["coverage"]
+                and not coverage._check_cached(self.coverage_hash)
+                and self.trace
+            ):
                 self._expand_trace()
             if not self.status:
                 if self._revert_msg is None:
@@ -191,10 +195,12 @@ class TransactionReceipt:
                 if self.contract_address:
                     source = ""
                 else:
-                    source = self._traceback_string() if ARGV["revert"] else self._error_string(1)
+                    source = (
+                        self._traceback_string() if CONFIG.argv["revert"] else self._error_string(1)
+                    )
                 raise VirtualMachineError({"message": self._revert_msg or "", "source": source})
         except KeyboardInterrupt:
-            if ARGV["cli"] != "console":
+            if CONFIG.mode != "console":
                 raise
 
     def __repr__(self) -> str:
@@ -358,12 +364,12 @@ class TransactionReceipt:
 
         try:
             trace = web3.provider.make_request(  # type: ignore
-                "debug_traceTransaction", (self.txid, {"disableStorage": ARGV["cli"] != "console"})
+                "debug_traceTransaction", (self.txid, {"disableStorage": CONFIG.mode != "console"})
             )
         except (requests.exceptions.Timeout, requests.exceptions.ConnectionError) as e:
             msg = f"Encountered a {type(e).__name__} while requesting "
             msg += "debug_traceTransaction. The local RPC client has likely crashed."
-            if ARGV["coverage"]:
+            if CONFIG.argv["coverage"]:
                 msg += " If the error persists, add the skip_coverage fixture to this test."
             raise RPCRequestError(msg) from None
 
@@ -493,13 +499,13 @@ class TransactionReceipt:
                     last["address"], trace[i]["stack"][-2][-40:], trace[i]["stack"][-3]
                 )
 
-            if "pc_map" not in last:
+            if not last["pc_map"]:
                 continue
             pc = last["pc_map"][trace[i]["pc"]]
 
             if "path" not in pc:
                 continue
-            trace[i]["source"] = {"filename": pc["path"], "offset": pc["offset"]}
+            trace[i]["source"] = {"filename": last["path_map"][pc["path"]], "offset": pc["offset"]}
 
             if "fn" not in pc:
                 continue
@@ -719,9 +725,7 @@ class TransactionReceipt:
             return ""
         contract = _find_contract(self.trace[idx]["address"])
         source, linenos = highlight_source(
-            contract._project._sources.get(trace["source"]["filename"]),
-            trace["source"]["offset"],
-            pad,
+            contract._sources.get(trace["source"]["filename"]), trace["source"]["offset"], pad
         )
         if not source:
             return ""
@@ -795,16 +799,20 @@ def _get_memory(step: Dict, idx: int) -> HexBytes:
 def _get_last_map(address: EthAddress, sig: str) -> Dict:
     contract = _find_contract(address)
     last_map = {"address": EthAddress(address), "jumpDepth": 0, "name": None, "coverage": False}
+
     if contract:
         last_map.update(
             contract=contract,
             name=contract._name,
             fn=[f"{contract._name}.{contract.get_method(sig)}"],
+            path_map=contract._build.get("allSourcePaths"),
+            pc_map=contract._build.get("pcMap"),
         )
-        if contract._build:
-            last_map.update(pc_map=contract._build["pcMap"], coverage=True)
+        if contract._project:
+            last_map["coverage"] = True
             if contract._build["language"] == "Solidity":
                 last_map["active_branches"] = set()
     else:
-        last_map.update(contract=None, fn=[f"<UnknownContract>.{sig}"])
+        last_map.update(contract=None, fn=[f"<UnknownContract>.{sig}"], pc_map=None)
+
     return last_map
