@@ -1,32 +1,36 @@
 #!/usr/bin/python3
 
-from typing import Dict, ItemsView, List, Optional, Sequence, Tuple, Union
+from typing import Dict, ItemsView, List, Optional, Tuple, Union
 
 from .sources import Sources, highlight_source
 
-BUILD_KEYS = [
+DEPLOYMENT_KEYS = [
     "abi",
-    "allSourcePaths",
     "ast",
     "bytecode",
-    "bytecodeSha1",
     "compiler",
     "contractName",
-    "coverageMap",
     "deployedBytecode",
     "deployedSourceMap",
-    "dependencies",
     "language",
-    "offset",
+    "natspec",
     "opcodes",
     "pcMap",
-    "sha1",
-    "source",
     "sourceMap",
-    "sourcePath",
     "type",
 ]
 
+BUILD_KEYS = [
+    "allSourcePaths",
+    "bytecodeSha1",
+    "coverageMap",
+    "dependencies",
+    "offset",
+    "sha1",
+    "source",
+    "sourcePath",
+] + DEPLOYMENT_KEYS
+
 _revert_map: Dict = {}
 
 
@@ -42,12 +46,12 @@ class Build:
         contract_name = build_json["contractName"]
         if "0" in build_json["pcMap"]:
             build_json["pcMap"] = dict((int(k), v) for k, v in build_json["pcMap"].items())
-        if build_json["compiler"]["minify_source"]:
-            build_json = self.expand_build_offsets(build_json)
         self._build[contract_name] = build_json
-        self._generate_revert_map(build_json["pcMap"], build_json["language"])
+        self._generate_revert_map(
+            build_json["pcMap"], build_json["allSourcePaths"], build_json["language"]
+        )
 
-    def _generate_revert_map(self, pcMap: Dict, language: str) -> None:
+    def _generate_revert_map(self, pcMap: Dict, source_map: Dict, language: str) -> None:
         # Adds a contract's dev revert strings to the revert map and it's pcMap
         marker = "//" if language == "Solidity" else "#"
         for pc, data in (
@@ -55,12 +59,16 @@ class Build:
             for k, v in pcMap.items()
             if v["op"] in ("REVERT", "INVALID") or "jump_revert" in v
         ):
+            if "path" not in data:
+                continue
+            path_str = source_map[data["path"]]
+
             if "dev" not in data:
                 if "fn" not in data or "first_revert" in data:
                     _revert_map[pc] = False
                     continue
                 try:
-                    revert_str = self._sources.get(data["path"])[data["offset"][1] :]
+                    revert_str = self._sources.get(path_str)[data["offset"][1] :]
                     revert_str = revert_str[: revert_str.index("\n")]
                     revert_str = revert_str[revert_str.index(marker) + len(marker) :].strip()
                     if revert_str.startswith("dev:"):
@@ -70,7 +78,7 @@ class Build:
 
             msg = "" if data["op"] == "REVERT" else "invalid opcode"
             revert = (
-                data["path"],
+                path_str,
                 tuple(data["offset"]),
                 data.get("fn", "<None>"),
                 data.get("dev", msg),
@@ -110,40 +118,6 @@ class Build:
     def _stem(self, contract_name: str) -> str:
         return contract_name.replace(".json", "")
 
-    def expand_build_offsets(self, build_json: Dict) -> Dict:
-        """Expands minified source offsets in a build json dict."""
-
-        offset_map: Dict = {}
-        name = build_json["contractName"]
-
-        # minification only happens to the target contract that was compiled,
-        # so we ignore any import sources
-        source_path = build_json["sourcePath"]
-
-        for value in (
-            v
-            for v in build_json["pcMap"].values()
-            if "offset" in v and "path" in v and v["path"] == source_path
-        ):
-            value["offset"] = self._get_offset(offset_map, name, value["offset"])
-
-        for key in ("branches", "statements"):
-            if source_path not in build_json["coverageMap"][key]:
-                continue
-            coverage_map = build_json["coverageMap"][key][source_path]
-            for fn, value in coverage_map.items():
-                coverage_map[fn] = dict(
-                    (k, self._get_offset(offset_map, name, v[:2]) + tuple(v[2:]))
-                    for k, v in value.items()
-                )
-        return build_json
-
-    def _get_offset(self, offset_map: Dict, name: str, offset: Sequence[int]) -> Tuple:
-        offset = tuple(offset)
-        if offset not in offset_map:
-            offset_map[offset] = self._sources.expand_offset(name, offset)
-        return offset_map[offset]
-
 
 def _get_dev_revert(pc: int) -> Optional[str]:
     # Given the program counter from a stack trace that caused a transaction
