@@ -22,7 +22,9 @@ from brownie.utils import color
 
 from . import compiler
 
-URI_REGEX = r"""^(?:erc1319://|)([^/:\s]*)(?::[0-9]+|)/([a-z][a-z0-9_-]{0,255})@([^\s:/'";]*)$"""
+URI_REGEX = (
+    r"""^(?:erc1319://|ethpm://|)([^/:\s]*)(?::[0-9]+|)/([a-z][a-z0-9_-]{0,255})@([^\s:/'";]*)$"""
+)
 
 REGISTRY_ABI = [
     {
@@ -158,8 +160,9 @@ def process_manifest(manifest: Dict, uri: Optional[str] = None) -> Dict:
                 {
                     "abi": build["abi"],
                     "source_path": build["sourcePath"],
-                    "all_source_paths": build["allSourcePaths"],
+                    "all_source_paths": sorted(build["allSourcePaths"].values()),
                     "compiler": build["compiler"],
+                    "natspec": build["natspec"],
                 }
             )
 
@@ -297,7 +300,7 @@ def install_package(project_path: Path, uri: str, replace_existing: bool = False
 
     Args:
         project_path: Path to the root folder of the project
-        uri: manifest URI, can be erc1319 or ipfs
+        uri: manifest URI, can be erc1319, ethpm or ipfs
         replace_existing: if True, existing files will be overwritten when
                             installing the package
 
@@ -640,10 +643,9 @@ def _get_contract_type(build_json: Dict, relative_to: str) -> Dict:
             runtime_bytecode={"bytecode": f"0x{build_json['deployedBytecode']}"},
         )
         if build_json["language"] == "Solidity":
-            contract_type["compiler"]["settings"]["optimizer"] = {
-                "enabled": build_json["compiler"]["optimize"],
-                "runs": build_json["compiler"]["runs"],
-            }
+            contract_type["compiler"]["settings"]["optimizer"] = build_json["compiler"].get(
+                "optimizer", {}
+            )
     return contract_type
 
 
