@@ -1,33 +1,36 @@
 #!/usr/bin/python3
 
 import json
+import os
 import shutil
 import sys
 import zipfile
+from base64 import b64encode
+from hashlib import sha1
 from io import BytesIO
 from pathlib import Path
-from typing import Any, Dict, Iterator, KeysView, List, Optional, Set, Union
+from typing import Any, Dict, Iterator, KeysView, List, Optional, Set, Tuple, Union
+from urllib.parse import urlparse
 
 import requests
 from semantic_version import Version
 from tqdm import tqdm
 
 from brownie._config import (
-    BROWNIE_FOLDER,
     CONFIG,
-    _get_project_config_path,
+    _get_data_folder,
     _load_project_compiler_config,
     _load_project_config,
+    _load_project_dependencies,
 )
-from brownie.exceptions import ProjectAlreadyLoaded, ProjectNotFound
+from brownie.exceptions import InvalidPackage, ProjectAlreadyLoaded, ProjectNotFound
 from brownie.network import web3
 from brownie.network.contract import Contract, ContractContainer, ProjectContract
 from brownie.network.state import _add_contract, _remove_contract
-from brownie.project import compiler
+from brownie.project import compiler, ethpm
 from brownie.project.build import BUILD_KEYS, Build
 from brownie.project.ethpm import get_deployment_addresses, get_manifest
-from brownie.project.sources import Sources, get_hash, get_pragma_spec
-from brownie.utils import color
+from brownie.project.sources import Sources, get_pragma_spec
 
 FOLDERS = [
     "contracts",
@@ -62,21 +65,30 @@ class _ProjectBase:
     _build: Build
 
     def _compile(self, contract_sources: Dict, compiler_config: Dict, silent: bool) -> None:
-        allow_paths = None
-        if self._path is not None:
-            allow_paths = self._path.joinpath("contracts").as_posix()
         compiler_config.setdefault("solc", {})
-        build_json = compiler.compile_and_format(
-            contract_sources,
-            solc_version=compiler_config["solc"].get("version", None),
-            optimize=compiler_config["solc"].get("optimize", None),
-            runs=compiler_config["solc"].get("runs", None),
-            evm_version=compiler_config["evm_version"],
-            minify=compiler_config["minify_source"],
-            silent=silent,
-            allow_paths=allow_paths,
-            interface_sources=self._sources.get_interface_sources(),
-        )
+
+        allow_paths = None
+        cwd = os.getcwd()
+        if self._path is not None:
+            _install_dependencies(self._path)
+            allow_paths = self._path.as_posix()
+            os.chdir(self._path)
+
+        try:
+            build_json = compiler.compile_and_format(
+                contract_sources,
+                solc_version=compiler_config["solc"].get("version", None),
+                optimize=compiler_config["solc"].get("optimize", None),
+                runs=compiler_config["solc"].get("runs", None),
+                evm_version=compiler_config["evm_version"],
+                silent=silent,
+                allow_paths=allow_paths,
+                remappings=compiler_config["solc"].get("remappings", []),
+                optimizer=compiler_config["solc"].get("optimizer", None),
+            )
+        finally:
+            os.chdir(cwd)
+
         for data in build_json.values():
             if self._path is not None:
                 path = self._path.joinpath(f"build/contracts/{data['contractName']}.json")
@@ -152,6 +164,13 @@ class Project(_ProjectBase):
             if not set(BUILD_KEYS).issubset(build_json) or path.stem not in contract_list:
                 path.unlink()
                 continue
+            if isinstance(build_json["allSourcePaths"], list):
+                # this handles the format change in v1.7.0, it can be removed in a future release
+                path.unlink()
+                test_path = self._path.joinpath("build/tests.json")
+                if test_path.exists():
+                    test_path.unlink()
+                continue
             self._build._add(build_json)
 
         self._compiler_config = _load_project_compiler_config(self._path)
@@ -219,15 +238,16 @@ class Project(_ProjectBase):
         except KeyError:
             return True
         # compare source hashes
-        hash_ = get_hash(source, contract_name, config["minify_source"], build_json["language"])
-        if build_json["sha1"] != hash_:
+        if build_json["sha1"] != sha1(source.encode()).hexdigest():
             return True
         # compare compiler settings
         if _compare_settings(config, build_json["compiler"]):
             return True
         if build_json["language"] == "Solidity":
             # compare solc-specific compiler settings
-            if _compare_settings(config["solc"], build_json["compiler"]):
+            solc_config = config["solc"].copy()
+            solc_config["remappings"] = None
+            if _compare_settings(solc_config, build_json["compiler"]):
                 return True
             # compare solc pragma against compiled version
             if Version(build_json["compiler"]["version"]) not in get_pragma_spec(source):
@@ -235,14 +255,12 @@ class Project(_ProjectBase):
         return False
 
     def _load_deployments(self) -> None:
-        if not CONFIG["active_network"].get("persist", None):
+        if CONFIG.network_type != "live":
             return
-        network = CONFIG["active_network"]["name"]
-        path = self._path.joinpath(f"build/deployments/{network}")
+        chainid = CONFIG.active_network["chainid"]
+        path = self._path.joinpath(f"build/deployments/{chainid}")
         path.mkdir(exist_ok=True)
-        deployments = list(
-            self._path.glob(f"build/deployments/{CONFIG['active_network']['name']}/*.json")
-        )
+        deployments = list(path.glob("*.json"))
         deployments.sort(key=lambda k: k.stat().st_mtime)
         for build_json in deployments:
             with build_json.open() as fp:
@@ -281,7 +299,7 @@ class Project(_ProjectBase):
                 brownie.__all__.remove(key)
 
     def __repr__(self) -> str:
-        return f"<Project '{color('bright magenta')}{self._name}{color}'>"
+        return f"<Project '{self._name}'>"
 
     def load_config(self) -> None:
         """Loads the project config file settings"""
@@ -341,14 +359,16 @@ class TempProject(_ProjectBase):
         self._create_containers()
 
     def __repr__(self) -> str:
-        return f"<TempProject '{color('bright magenta')}{self._name}{color}'>"
+        return f"<TempProject '{self._name}'>"
 
 
 def check_for_project(path: Union[Path, str] = ".") -> Optional[Path]:
     """Checks for a Brownie project."""
     path = Path(path).resolve()
     for folder in [path] + list(path.parents):
-        if _get_project_config_path(folder):
+        if next((i for i in folder.glob("contracts/**/*") if i.suffix in (".vy", ".sol")), None):
+            return folder
+        if folder.joinpath("contracts").is_dir() and folder.joinpath("tests").is_dir():
             return folder
     return None
 
@@ -358,29 +378,24 @@ def get_loaded_projects() -> List:
     return _loaded_projects.copy()
 
 
-def new(project_path_str: str = ".", ignore_subfolder: bool = False) -> str:
+def new(
+    project_path_str: str = ".", ignore_subfolder: bool = False, ignore_existing: bool = False
+) -> str:
     """Initializes a new project.
 
     Args:
         project_path: Path to initialize the project at. If not exists, it will be created.
-        ignore_subfolders: If True, will not raise if initializing in a project subfolder.
+        ignore_subfolder: (deprecated)
+        ignore_existing: If True, will not raise when initiating in a non-empty directory.
 
     Returns the path to the project as a string.
     """
-    project_path = _new_checks(project_path_str, ignore_subfolder)
+    project_path = Path(project_path_str).resolve()
+    if not ignore_existing and project_path.exists() and list(project_path.glob("*")):
+        raise FileExistsError(f"Directory is not empty: {project_path}")
     project_path.mkdir(exist_ok=True)
     _create_folders(project_path)
     _create_gitfiles(project_path)
-    if not _get_project_config_path(project_path):
-        shutil.copy(
-            BROWNIE_FOLDER.joinpath("data/brownie-config.yaml"),
-            project_path.joinpath("brownie-config.yaml"),
-        )
-    if not project_path.joinpath("ethpm-config.yaml").exists():
-        shutil.copy(
-            BROWNIE_FOLDER.joinpath("data/ethpm-config.yaml"),
-            project_path.joinpath("ethpm-config.yaml"),
-        )
     _add_to_sys_path(project_path)
     return str(project_path)
 
@@ -393,7 +408,7 @@ def from_brownie_mix(
 
     Args:
         project_path: Path to initialize the project at.
-        ignore_subfolders: If True, will not raise if initializing in a project subfolder.
+        ignore_subfolders: (deprecated)
 
     Returns the path to the project as a string.
     """
@@ -401,30 +416,15 @@ def from_brownie_mix(
     url = MIXES_URL.format(project_name)
     if project_path is None:
         project_path = Path(".").joinpath(project_name)
-    project_path = _new_checks(project_path, ignore_subfolder)
+    project_path = Path(project_path).resolve()
     if project_path.exists() and list(project_path.glob("*")):
         raise FileExistsError(f"Folder already exists - {project_path}")
 
     print(f"Downloading from {url}...")
-    response = requests.get(url, stream=True)
-    total_size = int(response.headers.get("content-length", 0))
-    progress_bar = tqdm(total=total_size, unit="iB", unit_scale=True)
-    content = bytes()
-
-    for data in response.iter_content(1024, decode_unicode=True):
-        progress_bar.update(len(data))
-        content += data
-    progress_bar.close()
-
-    with zipfile.ZipFile(BytesIO(content)) as zf:
-        zf.extractall(str(project_path.parent))
+    _stream_download(url, str(project_path.parent))
     project_path.parent.joinpath(project_name + "-mix-master").rename(project_path)
     _create_folders(project_path)
     _create_gitfiles(project_path)
-    shutil.copy(
-        BROWNIE_FOLDER.joinpath("data/brownie-config.yaml"),
-        project_path.joinpath("brownie-config.yaml"),
-    )
     _add_to_sys_path(project_path)
     return str(project_path)
 
@@ -438,7 +438,6 @@ def from_ethpm(uri: str) -> "TempProject":
     manifest = get_manifest(uri)
     compiler_config = {
         "evm_version": None,
-        "minify_source": False,
         "solc": {"version": None, "optimize": True, "runs": 200},
     }
     project = TempProject(manifest["package_name"], manifest["sources"], compiler_config)
@@ -449,17 +448,6 @@ def from_ethpm(uri: str) -> "TempProject":
     return project
 
 
-def _new_checks(project_path: Union[Path, str], ignore_subfolder: bool) -> Path:
-    project_path = Path(project_path).resolve()
-    if str(BROWNIE_FOLDER) in str(project_path):
-        raise SystemError("Cannot make a new project inside the main brownie installation folder.")
-    if not ignore_subfolder:
-        check = check_for_project(project_path)
-        if check and check != project_path:
-            raise SystemError("Cannot make a new project in a subfolder of an existing project.")
-    return project_path
-
-
 def compile_source(
     source: str,
     solc_version: Optional[str] = None,
@@ -470,7 +458,7 @@ def compile_source(
     """Compiles the given source code string and returns a TempProject container with
     the ContractContainer instances."""
 
-    compiler_config: Dict = {"evm_version": evm_version, "minify_source": False}
+    compiler_config: Dict = {"evm_version": evm_version}
 
     if solc_version is not None or source.lstrip().startswith("pragma"):
         compiler_config["solc"] = {"version": solc_version, "optimize": optimize, "runs": runs}
@@ -493,7 +481,9 @@ def load(project_path: Union[Path, str, None] = None, name: Optional[str] = None
     # checks
     if project_path is None:
         project_path = check_for_project(".")
-    if not project_path or not _get_project_config_path(Path(project_path)):
+    elif Path(project_path).resolve() != check_for_project(project_path):
+        project_path = None
+    if project_path is None:
         raise ProjectNotFound("Could not find Brownie project")
 
     project_path = Path(project_path).resolve()
@@ -513,6 +503,125 @@ def load(project_path: Union[Path, str, None] = None, name: Optional[str] = None
     return Project(name, project_path)
 
 
+def _install_dependencies(path: Path) -> None:
+    for package_id in _load_project_dependencies(path):
+        try:
+            install_package(package_id)
+        except FileExistsError:
+            pass
+
+
+def install_package(package_id: str) -> str:
+    """
+    Install a package.
+
+    Arguments
+    ---------
+    package_id : str
+        Package ID or ethPM URI.
+
+    Returns
+    -------
+    str
+        ID of the installed package.
+    """
+    if urlparse(package_id).scheme in ("erc1319", "ethpm"):
+        return _install_from_ethpm(package_id)
+    else:
+        return _install_from_github(package_id)
+
+
+def _install_from_ethpm(uri: str) -> str:
+    manifest = get_manifest(uri)
+    org = manifest["meta_brownie"]["registry_address"]
+    repo = manifest["package_name"]
+    version = manifest["version"]
+
+    install_path = _get_data_folder().joinpath(f"packages/{org}")
+    install_path.mkdir(exist_ok=True)
+    install_path = install_path.joinpath(f"{repo}@{version}")
+    if install_path.exists():
+        raise FileExistsError("Package is aleady installed")
+
+    try:
+        new(str(install_path), ignore_existing=True)
+        ethpm.install_package(install_path, uri)
+        project = load(install_path)
+        project.close()
+    except Exception as e:
+        shutil.rmtree(install_path)
+        raise e
+
+    return f"{org}/{repo}@{version}"
+
+
+def _install_from_github(package_id: str) -> str:
+    try:
+        path, version = package_id.split("@")
+        org, repo = path.split("/")
+    except ValueError:
+        raise ValueError(
+            "Invalid package ID. Must be given as [ORG]/[REPO]@[VERSION]"
+            "\ne.g. 'OpenZeppelin/openzeppelin-contracts@v2.5.0'"
+        ) from None
+
+    install_path = _get_data_folder().joinpath(f"packages/{org}")
+    install_path.mkdir(exist_ok=True)
+    install_path = install_path.joinpath(f"{repo}@{version}")
+    if install_path.exists():
+        raise FileExistsError("Package is aleady installed")
+
+    headers: Dict = {}
+    if os.getenv("GITHUB_TOKEN"):
+        auth = b64encode(os.environ["GITHUB_TOKEN"].encode()).decode()
+        headers = {"Authorization": "Basic {}".format(auth)}
+
+    response = requests.get(
+        f"https://api.github.com/repos/{org}/{repo}/tags?per_page=100", headers=headers
+    )
+    if response.status_code != 200:
+        msg = "Status {} when getting package versions from Github: '{}'".format(
+            response.status_code, response.json()["message"]
+        )
+        if response.status_code == 403:
+            msg += (
+                "\n\nIf this issue persists, generate a Github API token and store"
+                " it as the environment variable `GITHUB_TOKEN`:\n"
+                "https://github.blog/2013-05-16-personal-api-tokens/"
+            )
+        raise ConnectionError(msg)
+
+    data = response.json()
+    if not data:
+        raise ValueError("Github repository has no tags set")
+    org, repo = data[0]["zipball_url"].split("/")[3:5]
+    tags = [i["name"].lstrip("v") for i in data]
+    if version not in tags:
+        raise ValueError(
+            "Invalid version for this package. Available versions are:\n" + ", ".join(tags)
+        ) from None
+
+    download_url = next(i["zipball_url"] for i in data if i["name"].lstrip("v") == version)
+
+    existing = list(install_path.parent.iterdir())
+    _stream_download(download_url, str(install_path.parent))
+
+    installed = next(i for i in install_path.parent.iterdir() if i not in existing)
+    shutil.move(installed, install_path)
+
+    try:
+        if not install_path.joinpath("contracts").exists():
+            raise Exception
+        new(str(install_path), ignore_existing=True)
+        project = load(install_path)
+        project.close()
+    except Exception:
+        shutil.rmtree(install_path)
+        raise InvalidPackage(f"{package_id} cannot be interpreted as a Brownie project")
+
+    return f"{org}/{repo}@{version}"
+
+
 def _create_gitfiles(project_path: Path) -> None:
     gitignore = project_path.joinpath(".gitignore")
     if not gitignore.exists():
@@ -538,17 +647,37 @@ def _add_to_sys_path(project_path: Path) -> None:
 
 def _compare_settings(left: Dict, right: Dict) -> bool:
     return next(
-        (True for k, v in left.items() if v and not isinstance(v, dict) and v != right[k]), False
+        (True for k, v in left.items() if v and not isinstance(v, dict) and v != right.get(k)),
+        False,
     )
 
 
 def _load_sources(project_path: Path, subfolder: str, allow_json: bool) -> Dict:
     contract_sources: Dict = {}
+    suffixes: Tuple = (".sol", ".vy")
+    if allow_json:
+        suffixes = suffixes + (".json",)
+
     for path in project_path.glob(f"{subfolder}/**/*"):
-        if "/_" in path.as_posix() or path.suffix not in (".sol", ".vy", ".json"):
+        if "/_" in path.as_posix() or path.suffix not in suffixes:
             continue
         with path.open() as fp:
             source = fp.read()
         path_str: str = path.relative_to(project_path).as_posix()
         contract_sources[path_str] = source
     return contract_sources
+
+
+def _stream_download(download_url: str, target_path: str) -> None:
+    response = requests.get(download_url, stream=True)
+    total_size = int(response.headers.get("content-length", 0))
+    progress_bar = tqdm(total=total_size, unit="iB", unit_scale=True)
+    content = bytes()
+
+    for data in response.iter_content(1024, decode_unicode=True):
+        progress_bar.update(len(data))
+        content += data
+    progress_bar.close()
+
+    with zipfile.ZipFile(BytesIO(content)) as zf:
+        zf.extractall(target_path)
